@@ -720,12 +720,23 @@ pref("network.IDN.whitelist.vn", true);
 // IDN ccTLDs
 // ae, UAE, .<Emarat>
 pref("network.IDN.whitelist.xn--mgbaam7a8h", true); 
-// sa, Saudi Arabia, .<al-Saudiah>
-pref("network.IDN.whitelist.xn--mgberp4a5d4ar", true); 
-// ru, Russian Federation, .<RF>
-pref("network.IDN.whitelist.xn--p1ai", true);
+// cn, China, .<China> with variants
+pref("network.IDN.whitelist.xn--fiqz9s", true); // Traditional
+pref("network.IDN.whitelist.xn--fiqs8s", true); // Simplified
+// hk, Hong Kong, .<Hong Kong>
+pref("network.IDN.whitelist.xn--j6w193g", true);
 // jo, Jordan, .<Al-Ordon>
 pref("network.IDN.whitelist.xn--mgbayh7gpa", true);
+// ru, Russian Federation, .<RF>
+pref("network.IDN.whitelist.xn--p1ai", true);
+// sa, Saudi Arabia, .<al-Saudiah> with variants
+pref("network.IDN.whitelist.xn--mgberp4a5d4ar", true); 
+pref("network.IDN.whitelist.xn--mgberp4a5d4a87g", true);
+pref("network.IDN.whitelist.xn--mgbqly7c0a67fbc", true);
+pref("network.IDN.whitelist.xn--mgbqly7cvafr", true);
+// tw, Taiwan, <.Taiwan> with variants
+pref("network.IDN.whitelist.xn--kpry57d", true);  // Traditional
+pref("network.IDN.whitelist.xn--kprw13d", true);  // Simplified
 
 // gTLDs
 pref("network.IDN.whitelist.biz", true);
@@ -813,7 +824,7 @@ pref("network.negotiate-auth.gsslib", "");
 // Specify if the gss lib comes standard with the OS
 pref("network.negotiate-auth.using-native-gsslib", true);
 
-//@line 828 "/builds/slave/linux_build/build/mozilla/modules/libpref/src/init/all.js"
+//@line 839 "/builds/slave/linux_build/build/mozilla/modules/libpref/src/init/all.js"
 
 // The following prefs are used to enable automatic use of the operating
 // system's NTLM implementation to silently authenticate the user with their
@@ -832,9 +843,9 @@ pref("network.ntlm.send-lm-response", false);
 
 pref("permissions.default.image",           1); // 1-Accept, 2-Deny, 3-dontAcceptForeign
 
-//@line 848 "/builds/slave/linux_build/build/mozilla/modules/libpref/src/init/all.js"
+//@line 859 "/builds/slave/linux_build/build/mozilla/modules/libpref/src/init/all.js"
 pref("network.proxy.type",                  5);
-//@line 855 "/builds/slave/linux_build/build/mozilla/modules/libpref/src/init/all.js"
+//@line 866 "/builds/slave/linux_build/build/mozilla/modules/libpref/src/init/all.js"
 
 pref("network.proxy.ftp",                   "");
 pref("network.proxy.ftp_port",              0);
@@ -1196,15 +1207,15 @@ pref("font.minimum-size.x-western", 0);
 pref("font.minimum-size.x-unicode", 0);
 pref("font.minimum-size.x-user-def", 0);
 
-//@line 1595 "/builds/slave/linux_build/build/mozilla/modules/libpref/src/init/all.js"
+//@line 1606 "/builds/slave/linux_build/build/mozilla/modules/libpref/src/init/all.js"
 
-//@line 2012 "/builds/slave/linux_build/build/mozilla/modules/libpref/src/init/all.js"
+//@line 2023 "/builds/slave/linux_build/build/mozilla/modules/libpref/src/init/all.js"
 
-//@line 2213 "/builds/slave/linux_build/build/mozilla/modules/libpref/src/init/all.js"
+//@line 2224 "/builds/slave/linux_build/build/mozilla/modules/libpref/src/init/all.js"
 
-//@line 2307 "/builds/slave/linux_build/build/mozilla/modules/libpref/src/init/all.js"
+//@line 2318 "/builds/slave/linux_build/build/mozilla/modules/libpref/src/init/all.js"
 
-//@line 2310 "/builds/slave/linux_build/build/mozilla/modules/libpref/src/init/all.js"
+//@line 2321 "/builds/slave/linux_build/build/mozilla/modules/libpref/src/init/all.js"
 // Handled differently under Mac/Windows
 pref("network.hosts.smtp_server", "localhost");
 pref("network.hosts.pop_server", "pop");
@@ -1472,15 +1483,15 @@ pref("print.postscript.print_command", "lpr ${MOZ_PRINTER_NAME:+-P\"$MOZ_PRINTER
 // So, we have no reasons we should use non-toplevel window for popup.
 pref("ui.panel.default_level_parent", true);
 
-//@line 2580 "/builds/slave/linux_build/build/mozilla/modules/libpref/src/init/all.js"
+//@line 2591 "/builds/slave/linux_build/build/mozilla/modules/libpref/src/init/all.js"
 
-//@line 2648 "/builds/slave/linux_build/build/mozilla/modules/libpref/src/init/all.js"
+//@line 2659 "/builds/slave/linux_build/build/mozilla/modules/libpref/src/init/all.js"
 
-//@line 2674 "/builds/slave/linux_build/build/mozilla/modules/libpref/src/init/all.js"
+//@line 2685 "/builds/slave/linux_build/build/mozilla/modules/libpref/src/init/all.js"
 
-//@line 2694 "/builds/slave/linux_build/build/mozilla/modules/libpref/src/init/all.js"
+//@line 2705 "/builds/slave/linux_build/build/mozilla/modules/libpref/src/init/all.js"
 
-//@line 2702 "/builds/slave/linux_build/build/mozilla/modules/libpref/src/init/all.js"
+//@line 2713 "/builds/slave/linux_build/build/mozilla/modules/libpref/src/init/all.js"
 
 // Login Manager prefs
 pref("signon.rememberSignons",              true);
@@ -1504,7 +1515,7 @@ pref("image.cache.size", 5242880);
 // Size is given a weight of 1000 - timeweight.
 pref("image.cache.timeweight", 500);
 
-//@line 2731 "/builds/slave/linux_build/build/mozilla/modules/libpref/src/init/all.js"
+//@line 2742 "/builds/slave/linux_build/build/mozilla/modules/libpref/src/init/all.js"
 
 // Enable/Disable the geolocation API for content
 pref("geo.enabled", true);
